Installation
============

All the requirements are listed in the file `env.yml`. It can be used to create a conda environement as follows:

.. code::

    conda env create -n kernax -f env.yml


Then add the package to your PYTHONPATH or simply do 

.. code::

    pip install -e .


Windows support
===============

JAX is now available on Windows, see JAX's official documentation.